@@ -1,32 +1,17 @@
 /*
-    Copyright 2005-2007 Kevin Ottens <ervin@kde.org>
+    SPDX-FileCopyrightText: 2005-2007 Kevin Ottens <ervin@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library. If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #include "haldevice.h"
 
-#include <QtCore/QDebug>
-#include <QtDBus/QDBusConnection>
-#include <QtDBus/QDBusInterface>
-#include <QtDBus/QDBusReply>
-#include <QtDBus/QDBusArgument>
-#include <QtDBus/QDBusMetaType>
-#include <QtDBus/QDBusVariant>
+#include <QDebug>
+#include <QDBusConnection>
+#include <QDBusInterface>
+#include <QDBusReply>
+#include <QDBusArgument>
+#include <QDBusMetaType>
 
 #include <solid/genericinterface.h>
 
@@ -95,7 +80,7 @@ public:
                  udi,
                  "org.freedesktop.Hal.Device",
                  QDBusConnection::systemBus()),
-        cacheSynced(false), parent(0) { }
+        cacheSynced(false), parent(nullptr) { }
     void checkCache(const QString &key = QString());
 
     QDBusInterface device;
@@ -382,9 +367,8 @@ bool HalDevice::queryDeviceInterface(const Solid::DeviceInterface::Type &type) c
         return d->capListCache.value(type);
     }
 
-    QStringList cap_list = DeviceInterface::toStringList(type);
-
-    Q_FOREACH (const QString &cap, cap_list) {
+    const QStringList cap_list = DeviceInterface::toStringList(type);
+    for (const QString &cap : cap_list) {
         QDBusReply<bool> reply = d->device.call("QueryCapability", cap);
 
         if (!reply.isValid()) {
@@ -405,7 +389,7 @@ bool HalDevice::queryDeviceInterface(const Solid::DeviceInterface::Type &type) c
 QObject *HalDevice::createDeviceInterface(const Solid::DeviceInterface::Type &type)
 {
     if (!queryDeviceInterface(type)) {
-        return 0;
+        return nullptr;
     }
 
     DeviceInterface *iface = nullptr;
@@ -458,7 +442,7 @@ void HalDevice::slotPropertyModified(int /*count */, const QList<ChangeDescripti
 {
     QMap<QString, int> result;
 
-    Q_FOREACH (const ChangeDescription &change, changes) {
+    for (const ChangeDescription &change : changes) {
         QString key = change.key;
         bool added = change.added;
         bool removed = change.removed;
