@@ -1,21 +1,7 @@
 /*
-    Copyright 2005,2006 Kevin Ottens <ervin@kde.org>
+    SPDX-FileCopyrightText: 2005, 2006 Kevin Ottens <ervin@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library. If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #include "halmanager.h"
@@ -137,7 +123,8 @@ QStringList HalManager::devicesFromQuery(const QString &parentUdi,
 
     QStringList result;
 
-    Q_FOREACH (const QString &udi, allDevices()) {
+    const QStringList deviceList = allDevices();
+    for (const QString &udi : deviceList) {
         HalDevice device(udi);
 
         if ((!parentUdi.isEmpty()) && (parentUdi != device.parentUdi())) {
@@ -159,7 +146,7 @@ QObject *HalManager::createDevice(const QString &udi)
     if (deviceExists(udi)) {
         return new HalDevice(udi);
     } else {
-        return 0;
+        return nullptr;
     }
 }
 
